==> odp_sdk-0.25.7.tar.gz: odp_sdk-0.25.7/odp/tabular_v2/client/client.py <==
import io
import logging
from typing import TYPE_CHECKING, Dict, Iterator, Optional, Union

import requests

from odp.tabular_v2.util import Iter2Reader, size2human

if TYPE_CHECKING:
    from odp.tabular_v2.client.table import Table


class Client:
    def __init__(self, base_url: str):
        self._base_url = base_url

    class Response:
        # Abstraction for response object, shared between http client and test client
        def __init__(self, res: Union[requests.Response, Iterator[bytes], Dict, bytes]):
            if isinstance(res, requests.Response):
                if res.status_code == 204:
                    raise FileNotFoundError(res.text)
                res.raise_for_status()
            # logging.info("response: %s", res)
            self.res = res

        def reader(self):
            if isinstance(self.res, bytes):
                return io.BytesIO(self.res)
            if isinstance(self.res, Iterator):
                return Iter2Reader(self.res)
            return self.res.raw

        def iter(self) -> Iterator[bytes]:
            if isinstance(self.res, bytes):
                return iter([self.res])
            if isinstance(self.res, Iterator):
                return self.res
            return self.res.iter_content()

        def all(self) -> bytes:
            if isinstance(self.res, bytes):
                return self.res
            if isinstance(self.res, Iterator):
                return b"".join(self.res)
            return self.res.content

        def json(self) -> dict:
            if isinstance(self.res, dict):
                return self.res
            return self.res.json()

    def _request(
        self,
        path: str,
        data: Union[Dict, bytes, None] = None,
        params: Optional[Dict] = None,
        headers: Optional[Dict] = None,
    ) -> Response:
        logging.info("sending %s %s (%s)", path, params, size2human(len(data)) if data else "-")
        if isinstance(data, dict):
            res = requests.post(self._base_url + path, headers=headers, params=params, json=data, stream=True)
        elif isinstance(data, bytes):
            res = requests.post(self._base_url + path, headers=headers, params=params, data=data, stream=True)
        elif isinstance(data, Iterator):
            res = requests.post(self._base_url + path, headers=headers, params=params, data=data, stream=True)
        elif data is None:
            res = requests.post(self._base_url + path, headers=headers, params=params, stream=True)
        else:
            raise ValueError(f"unexpected type {type(data)}")
        logging.info("got response %s", res.status_code)
        return self.Response(res)

    def table(self, table_id: str) -> "Table":
        from odp.tabular_v2.client import Table

        return Table(self, table_id)

==> odp_sdk-0.25.14.tar.gz: odp_sdk-0.25.14/odp/tabular_v2/client/client.py <==
import io
import logging
from typing import TYPE_CHECKING, Dict, Iterator, Optional, Union

import requests
from requests.adapters import HTTPAdapter

from odp.tabular_v2.util import Iter2Reader, size2human

if TYPE_CHECKING:
    from odp.tabular_v2.client.table import Table


class Client:
    def __init__(self, base_url: str):
        self._base_url = base_url
        self._session = requests.Session()
        adapter = HTTPAdapter(pool_connections=4, pool_maxsize=4, max_retries=8)
        self._session.mount("http://", adapter)
        self._session.mount("https://", adapter)

    class Response:
        # Abstraction for response object, shared between http client and test client
        def __init__(self, res: Union[requests.Response, Iterator[bytes], Dict, bytes]):
            if isinstance(res, requests.Response):
                if res.status_code == 204:
                    raise FileNotFoundError(res.text)
                res.raise_for_status()
            # logging.info("response: %s", res)
            self.res = res

        def reader(self):
            if isinstance(self.res, bytes):
                return io.BytesIO(self.res)
            if isinstance(self.res, Iterator):
                return Iter2Reader(self.res)
            return self.res.raw

        def iter(self) -> Iterator[bytes]:
            if isinstance(self.res, bytes):
                return iter([self.res])
            if isinstance(self.res, Iterator):
                return self.res
            return self.res.iter_content()

        def all(self) -> bytes:
            if isinstance(self.res, bytes):
                return self.res
            if isinstance(self.res, Iterator):
                return b"".join(self.res)
            return self.res.content

        def json(self) -> dict:
            if isinstance(self.res, dict):
                return self.res
            return self.res.json()

    def _request(
        self,
        path: str,
        data: Union[Dict, bytes, None] = None,
        params: Optional[Dict] = None,
        headers: Optional[Dict] = None,
    ) -> Response:
        logging.info("sending %s %s (%s)", path, params, size2human(len(data)) if data else "-")
        if isinstance(data, dict):
            res = self._session.post(self._base_url + path, headers=headers, params=params, json=data, stream=True)
        elif isinstance(data, bytes):
            res = self._session.post(self._base_url + path, headers=headers, params=params, data=data, stream=True)
        elif isinstance(data, Iterator):
            res = self._session.post(self._base_url + path, headers=headers, params=params, data=data, stream=True)
        elif data is None:
            res = self._session.post(self._base_url + path, headers=headers, params=params, stream=True)
        else:
            raise ValueError(f"unexpected type {type(data)}")
        logging.info("got response %s", res.status_code)
        return self.Response(res)

    def table(self, table_id: str) -> "Table":
        """
        create a table handler for the given table_id
        @param table_id:
        @return:
        """
        from odp.tabular_v2.client import Table

        return Table(self, table_id)
